@@ -1,7 +1,6 @@
 import unittest
-import numpy as np
-from gillespy2.example_models import Example
-from gillespy2.solvers.numpy.ssa_solver import NumPySSASolver
+from example_models import Example
+from gillespy2 import NumPySSASolver
 
 
 class TestNumPySSASolver(unittest.TestCase):
